/***************************************************************************
 *   Copyright (C) 2005 by Spiros Georgaras                                *
 *   sngeorgaras@otenet.gr                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/


#ifndef __TDEFILE_MHTML_H__
#define __TDEFILE_MHTML_H__

/**
 * Note: For further information look into <$TDEDIR/include/tdefilemetainfo.h>
 */
#include <tdefilemetainfo.h>

class TQStringList;

class mhtmlPlugin: public KFilePlugin
{
    TQ_OBJECT
  
    
public:
    mhtmlPlugin( TQObject *parent, const char *name, const TQStringList& args );
    virtual bool readInfo( KFileMetaInfo& info, uint what);
private:
	TQString decodeRFC2047Phrase(const TQString &msg, bool removeLessGreater=true);
	TQString decodeRFC2047String(const TQString &msg);
};

#endif // __TDEFILE_MHTML_H__

